@@ -4,7 +4,9 @@ use std::path::Path;
 
 use tracing::debug;
 
-use crate::build_tools::{cargo, elm, flutter, mix, npm, BuildTool, BuildToolKind, BuildToolProbe};
+use crate::build_tools::{
+    cargo, elm, flutter, gradle, mix, npm, BuildTool, BuildToolKind, BuildToolProbe,
+};
 
 pub struct BuildToolManager {
     probes: Vec<Box<dyn BuildToolProbe>>,
@@ -17,11 +19,11 @@ impl Default for BuildToolManager {
         cargo::register(&mut build_tool_manager);
         elm::register(&mut build_tool_manager);
         flutter::register(&mut build_tool_manager);
+        gradle::register(&mut build_tool_manager);
         mix::register(&mut build_tool_manager);
         npm::register(&mut build_tool_manager);
 
         // TODO: Activate those as soon as the tests are there:
-        // gradle::register(&mut build_tool_manager);
         // maven::register(&mut build_tool_manager);
 
         build_tool_manager
