@@ -20,7 +20,11 @@ pub fn projects_below<'a>(
         .build()
         // ignore any errors
         .filter_map(|result| result.ok())
+        // iterate on directory entries only
+        .filter(|entry| entry.path().is_dir())
+        // get rid of symlinks, double slashes, etc.
         .filter_map(|entry| entry.path().canonicalize().ok())
+        // check if there is a project at this location
         .filter_map(
             |path| match Project::from_dir(&path, project_filter, build_tool_manager) {
                 Ok(maybe_project) => maybe_project,
@@ -44,7 +48,7 @@ mod test {
 
     use crate::{
         build_tool_manager::BuildToolManager,
-        build_tools::{BuildTool, BuildToolProbe},
+        build_tools::{BuildTool, BuildToolKind, BuildToolProbe},
         project::{Project, ProjectFilter, StatusFilter},
     };
 
@@ -74,7 +78,7 @@ mod test {
             }
         }
 
-        fn applies_to(&self, _: &str) -> bool {
+        fn applies_to(&self, _: BuildToolKind) -> bool {
             unimplemented!("not executed in these tests")
         }
     }
