@@ -15,6 +15,8 @@ where
             "--no-pub",
             "--project-name",
             "flutter_test_project",
+            "--platforms",
+            "linux",
             ".",
         ])
         .current_dir(parent.as_ref())
